@@ -25,10 +25,6 @@ class DatabaseCreation(PostgresDatabaseCreation):
             # greatest(): expected avg(price) to be of type float, found type
             # decimal: https://github.com/cockroachdb/django-cockroachdb/issues/74
             'aggregation.tests.AggregateTestCase.test_expression_on_aggregation',
-            # stddev/variance functions not supported:
-            # https://github.com/cockroachdb/django-cockroachdb/issues/25
-            'aggregation.test_filter_argument.FilteredAggregateTests.test_filtered_numerical_aggregates',
-            'aggregation_regress.tests.AggregationTests.test_stddev',
             # POWER() doesn't support negative exponents:
             # https://github.com/cockroachdb/django-cockroachdb/issues/22
             'db_functions.math.test_power.PowerTests.test_integer',
@@ -48,7 +44,6 @@ class DatabaseCreation(PostgresDatabaseCreation):
             'queries.test_bulk_update.BulkUpdateNoteTests.test_multiple_fields',
             'queries.test_bulk_update.BulkUpdateTests.test_inherited_fields',
             'queries.tests.Queries1Tests.test_ticket9411',
-            'queries.tests.Ticket14056Tests.test_ticket_14056',
             'queries.tests.RelatedLookupTypeTests.test_values_queryset_lookup',
             'syndication_tests.tests.SyndicationFeedTest.test_rss2_feed',
             'syndication_tests.tests.SyndicationFeedTest.test_latest_post_date',
@@ -59,24 +54,14 @@ class DatabaseCreation(PostgresDatabaseCreation):
             # Unsupported query: mixed type addition in SELECT:
             # https://github.com/cockroachdb/django-cockroachdb/issues/19
             'annotations.tests.NonAggregateAnnotationTestCase.test_mixed_type_annotation_numbers',
-            # Nondeterministic query: https://github.com/cockroachdb/django-cockroachdb/issues/48
-            'queries.tests.SubqueryTests.test_slice_subquery_and_query',
             # Forward references in fixtures won't work until cockroachdb can
             # disable constraints: https://github.com/cockroachdb/cockroach/issues/19444
             'serializers.test_data.SerializerDataTests.test_json_serializer',
             'serializers.test_data.SerializerDataTests.test_python_serializer',
             'serializers.test_data.SerializerDataTests.test_xml_serializer',
             'serializers.test_data.SerializerDataTests.test_yaml_serializer',
-            # cockroachdb doesn't distinguish between tables and views. Both
-            # are included regardless of whether inspectdb's --include-views
-            # option is set.
-            'inspectdb.tests.InspectDBTransactionalTests.test_include_views',
-            'introspection.tests.IntrospectionTests.test_table_names_with_views',
             # No sequence for AutoField in cockroachdb.
             'introspection.tests.IntrospectionTests.test_sequence_list',
-            # CharField max_length is ignored on cockroachdb. CharField is
-            # introspected as TextField.
-            'introspection.tests.IntrospectionTests.test_get_table_description_col_lengths',
             # Unsupported query: unsupported binary operator: <int> / <int>:
             # https://github.com/cockroachdb/django-cockroachdb/issues/21
             'expressions.tests.ExpressionOperatorTests.test_lefthand_division',
@@ -247,6 +232,23 @@ class DatabaseCreation(PostgresDatabaseCreation):
                 'transaction_hooks.tests.TestConnectionOnCommit.test_discards_hooks_from_rolled_back_savepoint',
                 'transaction_hooks.tests.TestConnectionOnCommit.test_inner_savepoint_rolled_back_with_outer',
                 'transaction_hooks.tests.TestConnectionOnCommit.test_inner_savepoint_does_not_affect_outer',
+                # CharField max_length is ignored on cockroachdb. CharField is
+                # introspected as TextField.
+                'introspection.tests.IntrospectionTests.test_get_table_description_col_lengths',
+            )
+        if not self.connection.features.is_cockroachdb_20_2:
+            expected_failures += (
+                # stddev/variance functions not supported:
+                # https://github.com/cockroachdb/django-cockroachdb/issues/25
+                'aggregation.test_filter_argument.FilteredAggregateTests.test_filtered_numerical_aggregates',
+                'aggregation_regress.tests.AggregationTests.test_stddev',
+                # Nondeterministic query: https://github.com/cockroachdb/django-cockroachdb/issues/48
+                'queries.tests.SubqueryTests.test_slice_subquery_and_query',
+                # `SHOW TABLES` doesn't distinguish between tables and views.
+                # Both are included regardless of whether inspectdb's
+                # --include-views option is set.
+                'inspectdb.tests.InspectDBTransactionalTests.test_include_views',
+                'introspection.tests.IntrospectionTests.test_table_names_with_views',
             )
         for test_name in expected_failures:
             test_case_name, _, method_name = test_name.rpartition('.')
@@ -280,6 +282,21 @@ class DatabaseCreation(PostgresDatabaseCreation):
             # CockroachDB has more restrictive blocking than other databases.
             # https://github.com/cockroachdb/django-cockroachdb/issues/153#issuecomment-664697963
             'select_for_update.tests.SelectForUpdateTests.test_block',
+            # Since QuerySet.select_for_update() was enabled, this test is
+            # already skipped by the 'Database took too long to lock the row'
+            # logic in the test. Skipping it entirely prevents some error
+            # output in the logs:
+            # Exception in thread Thread-1:
+            # ...
+            # psycopg2.errors.SerializationFailure: restart transaction:
+            # TransactionRetryWithProtoRefreshError: WriteTooOldError: write
+            # at timestamp 1598314405.858850941,0 too old; wrote at
+            # 1598314405.883337663,1
+            'get_or_create.tests.UpdateOrCreateTransactionTests.test_creation_in_transaction',
+            # Sometimes fails as above or with
+            # AssertionError: datetime.timedelta(microseconds=28529) not
+            # greater than datetime.timedelta(microseconds=500000)
+            'get_or_create.tests.UpdateOrCreateTransactionTests.test_updates_in_transaction',
         )
         for test_name in skip_tests:
             test_case_name, _, method_name = test_name.rpartition('.')
