@@ -10,14 +10,14 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
     has_select_for_update = property(operator.attrgetter('is_cockroachdb_20_1'))
     has_select_for_update_of = property(operator.attrgetter('is_cockroachdb_20_1'))
     # Not supported: https://github.com/cockroachdb/cockroach/issues/40476
-    has_select_for_update_nowait = False
+    has_select_for_update_nowait = property(operator.attrgetter('is_cockroachdb_20_2'))
     has_select_for_update_skip_locked = False
 
     # Not supported: https://github.com/cockroachdb/cockroach/issues/31632
     can_defer_constraint_checks = False
 
     # Not supported: https://github.com/cockroachdb/cockroach/issues/9683
-    supports_partial_indexes = False
+    supports_partial_indexes = property(operator.attrgetter('is_cockroachdb_20_2'))
 
     uses_savepoints = property(operator.attrgetter('is_cockroachdb_20_1'))
     can_release_savepoints = property(operator.attrgetter('is_cockroachdb_20_1'))
@@ -56,9 +56,13 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
     # Not supported: https://github.com/cockroachdb/cockroach/issues/41645
     supports_regex_backreferencing = False
 
+    # CockroachDB sorts NULL values first with ASC and last with DESC.
+    # PostgreSQL behaves the opposite.
+    nulls_order_largest = False
+
     # Introspection may work but 'CREATE MATERIALIZED VIEW' (required for the
     # test) isn't implemented: https://github.com/cockroachdb/cockroach/issues/41649
-    can_introspect_materialized_views = False
+    can_introspect_materialized_views = property(operator.attrgetter('is_cockroachdb_20_2'))
 
     introspected_big_auto_field_type = 'BigIntegerField'
 
@@ -66,6 +70,17 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
     # report column ordering: https://github.com/cockroachdb/cockroach/issues/42175
     supports_index_column_ordering = property(operator.attrgetter('is_cockroachdb_20_1'))
 
+    # CockroachDB stopped creating indexes on foreign keys in 20.2.
+    indexes_foreign_keys = property(operator.attrgetter('is_not_cockroachdb_20_2'))
+
     @cached_property
     def is_cockroachdb_20_1(self):
         return self.connection.cockroachdb_version >= (20, 1)
+
+    @cached_property
+    def is_cockroachdb_20_2(self):
+        return self.connection.cockroachdb_version >= (20, 2)
+
+    @cached_property
+    def is_not_cockroachdb_20_2(self):
+        return self.connection.cockroachdb_version < (20, 2)
